/*
**	This file is part of XDowl
**	Copyright (c) 1994 Jamie Mazer
**	California Institute of Technology
**	<mazer@asterix.cns.caltech.edu>
*/

/******************************************************************
**  RCSID: $Id: waver.h,v 2.45 2002/07/15 04:30:25 cmalek Exp $
** Program: dowl
**  Module: waver.h
**  Author: mazer
** Descrip: interface for waver.c
**
** Revision History (most recent last)
**
** Wed Oct 13 00:29:33 1993 mazer
**  deleted plotWave(), plotWave2(), setCursor(), clrCursor(),
**    popwaver_new()
**  changed waver_new() to canvaswaver_new()
**
*********************************************************************/

struct WavefileViewData {
	Widget nlabel, clabel;
	Widget left, right;
	int cpos;
	char *filename;
};

extern Widget canvaswaver_new(Widget, Dimension, Dimension);
extern void plotUnitPerievent(Widget, xword *, int, int, int, int, int,
			      int *, int, int, int);
extern Widget popfilewaver_new(Widget, char *, int, Dimension, Dimension,
			       Widget *, Widget *, char **);
extern Widget popfilewaver2_new(Widget, char *, Dimension, Dimension);
extern Widget waveview_new(Widget, Widget *, Widget *, int, int);
